@@ -27,11 +27,11 @@ class ValidationError(DitError):
 class CodeError(DitError):
     """Raised when a code block has any kind of language specifc error"""
 
-    def __init__(self, error: CalledProcessError, class_,
+    def __init__(self, error: CalledProcessError, name: str,
                  purpose: str, lang: dict):
         message = (
-            f'{class_.name} {lang["name"]} {purpose}\n'
-            f'Error message follows:\n\n{error.stderr.decode("utf-8")}')
+            f'{name} {lang["name"]} {purpose}\n'
+            f'Error message follows:\n\n{error.stderr.decode()}')
         super().__init__('CodeError', message)
 
 
@@ -42,8 +42,22 @@ class ParseError(DitError):
         super().__init__('ParseError', message)
 
 
-class TreeError(DitError):
-    """Raised when anything goes wrong with tree functions"""
+class NodeError(DitError):
+    """Raised when anything goes wrong with a node"""
 
     def __init__(self, message):
-        super().__init__('TreeError', message)
+        super().__init__('NodeError', message)
+
+
+class AssignError(DitError):
+    """Raised when anything goes wrong with an assigner"""
+
+    def __init__(self, message):
+        super().__init__('AssignError', message)
+
+
+class VarError(DitError):
+    """Raised when anything goes wrong with variables"""
+
+    def __init__(self, message):
+        super().__init__('VarError', message)
