@@ -70,11 +70,18 @@ def _parse_class(dit: str, namespace: Namespace) -> str:
             class_.add_extend(expr)
         dit = _rep_strip(dit, line)
 
+    if len(dit) == 0:
+        raise ParseError('Unexpected EOF while parsing class.')
+
     while dit[0] != '}':
+        if dit[:2] == '//':
+            dit = _parse_comment(dit)
+            continue
+
         end = _nearest_token(dit, [';', '{{'])
         line = dit[:dit.find(end) + len(end)]
         token = _nearest_token(
-            line, ['extends', ';', 'print', 'validator', '//', 'list'])
+            line, ['extends', ';', 'print', 'validator', 'list'])
         if token == 'extends':
             raise ParseError('"extends" must come first, or not at all')
         elif token == ';':
@@ -99,8 +106,6 @@ def _parse_class(dit: str, namespace: Namespace) -> str:
             lang = find_name(_rep_strip(dit, 'validator'))
             (dit, code) = _parse_escape(dit, '{{', '}}', '@@')
             class_.set_validator(code, lang)
-        elif token == '//':
-            dit = _parse_comment(dit)
         elif token == 'list':
             # 'list some_class some_object_name;'
             _regex_helper(line, r'^list \s*expr \s*name;$', 'list')
@@ -108,8 +113,10 @@ def _parse_class(dit: str, namespace: Namespace) -> str:
             (type_expr, var_name) = res
             class_.add_attribute(type_expr, var_name, list_=True)
 
-        if end == ';' and token != '//':
+        if end == ';':
             dit = _rep_strip(dit, line)
+        if len(dit) == 0:
+            raise ParseError('Unexpected EOF while parsing class.')
 
     return _rep_strip(dit, '}')
 
@@ -180,6 +187,8 @@ def _parse_assign(dit: str, namespace: Namespace) -> str:
     left_expr = parse_expr(left)
     namespace.raise_if_undefined(left_expr)
     dit = _rep_strip(dit, left)
+    if len(dit) == 0:
+        raise ParseError('Unexpected EOF while parsing assignment.')
 
     memory = []  # For opened lists and assigners
     data = []  # For all previously added values
@@ -226,10 +235,10 @@ def _parse_assign(dit: str, namespace: Namespace) -> str:
             else:
                 data.append(namespace.read_data(expr))
         else:
-            raise ParseError('Expected ";"')
+            raise ParseError('Expected ";" after assignment')
 
         if len(dit) == 0:
-            raise ParseError('Expected ";"')
+            raise ParseError('Expected ";" after assignment')
         if dit[0] == ',':
             dit = _rep_strip(dit, ',')
 
@@ -340,11 +349,9 @@ def _parse_import(dit: str, namespace: Namespace) -> str:
     dit = _rep_strip(dit, name)
     dit = _rep_strip(dit, 'from')
     token = dit[0]
-    if token not in ['"', "'"]:
-        raise ParseError(f'Import failed, expected string, not "{token}"')
     (dit, path) = _parse_escape(dit, token, token, '\\')
     if dit[0] != ';':
-        raise ParseError(f'Expected semicolon after import')
+        raise ParseError(f'Expected ";" after import')
     dit = _rep_strip(dit, ';')
 
     if path.startswith('https://') or path.startswith('http://'):
@@ -358,6 +365,9 @@ def _parse_import(dit: str, namespace: Namespace) -> str:
                 imported_dit = file_object.read()
         except FileNotFoundError:
             raise ParseError(f'Import failed, file not found\nPath: "{path}"')
+        except PermissionError:
+            raise ParseError(
+                f'Import failed, permission denied\nPath: "{path}"')
 
     if not imported_dit:
         raise ParseError(f'Import failed, reason unknown\nPath: "{path}"')
